pyxmpp.all

Package pyxmpp :: Module all |
[hide private]

# Source Code for Module pyxmpp.all

     1  #
     2  # (C) Copyright 2003-2010 Jacek Konieczny <jajcus@jajcus.net>
     3  #
     4  # This program is free software; you can redistribute it and/or modify
     5  # it under the terms of the GNU Lesser General Public License Version
     6  # 2.1 as published by the Free Software Foundation.
     7  #
     8  # This program is distributed in the hope that it will be useful,
     9  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    10  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    11  # GNU Lesser General Public License for more details.
    12  #
    13  # You should have received a copy of the GNU Lesser General Public
    14  # License along with this program; if not, write to the Free Software
    15  # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
    16  #
    17  # pylint: disable-msg=W0611
    18
    19  """Convenience module containing most important objects from pyxmpp package.
    20
    21  Suggested usage::
    22  import pyxmpp.all
    23
    24  (imports all important names into pyxmpp namespace)"""
    25
    26  """PyXMPP - Jabber/XMPP protocol implementation"""
    27
    28  __revision__="$Id: __init__.py 477 2004-12-29 13:25:42Z jajcus $"
    29  __docformat__="restructuredtext en"
    30
    31  import pyxmpp
    32
    33  from pyxmpp.stream import Stream
    34  from pyxmpp.streambase import StreamError,FatalStreamError,StreamParseError
    35  from pyxmpp.streamtls import StreamEncryptionRequired,tls_available,TLSSettings
    36  from pyxmpp.clientstream import ClientStream,ClientStreamError
    37  from pyxmpp.client import Client,ClientError
    38  from pyxmpp.iq import Iq
    39  from pyxmpp.presence import Presence
    40  from pyxmpp.message import Message
    41  from pyxmpp.jid import JID,JIDError
    42  from pyxmpp.roster import Roster,RosterItem
    43  from pyxmpp.exceptions import *
    44
    45  for name in dir():
    46      if not name.startswith("_") and name != "pyxmpp":
    47          setattr(pyxmpp,name,globals()[name])
    48
    49  # vi: sts=4 et sw=4
    50